import { Injectable } from '@angular/core';
import { HttpHeaders, HttpClient } from '@angular/common/http';
import { AuthenticationService } from 'ngx-login-client';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/catch';
import 'rxjs/operators/map';
var FeedbackService = /** @class */ (function () {
    function FeedbackService(http, auth) {
        this.http = http;
        this.auth = auth;
        this.headers = new HttpHeaders({ 'Content-Type': 'application/json' });
        if (this.auth.getToken() !== null) {
            this.headers.set('Authorization', 'Bearer ' + this.auth.getToken());
        }
    }
    FeedbackService.prototype.submit = function (feedback) {
        var url = 'https://recommender.api.openshift.io/api/v1/user-feedback';
        var options = {
            headers: this.headers
        };
        return this.http
            .post(url, JSON.stringify(feedback), options)
            .map(this.extractData)
            .catch(this.handleError);
    };
    FeedbackService.prototype.extractData = function (body) {
        return body || {};
    };
    FeedbackService.prototype.handleError = function (error) {
        var errMsg;
        if (error.error instanceof ErrorEvent) {
            errMsg = error.error.message || error.error.toString();
        }
        else {
            var body = error.error || '';
            var err = body.error || JSON.stringify(body);
            errMsg = error.status + " - " + (error.statusText || '') + " " + err;
        }
        return Observable.throw(errMsg);
    };
    FeedbackService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    FeedbackService.ctorParameters = function () { return [
        { type: HttpClient, },
        { type: AuthenticationService, },
    ]; };
    return FeedbackService;
}());
export { FeedbackService };
//# sourceMappingURL=feedback.service.js.map