import { Injectable } from '@angular/core';
import { HttpHeaders, HttpClient } from '@angular/common/http';
import { AuthenticationService } from 'ngx-login-client';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/catch';
import 'rxjs/operators/map';
var PipelineInsightsService = /** @class */ (function () {
    function PipelineInsightsService(http, auth) {
        this.http = http;
        this.auth = auth;
        this.headers = new HttpHeaders({ 'Content-Type': 'application/json' });
        if (this.auth.getToken() !== null) {
            this.headers.set('Authorization', 'Bearer ' + this.auth.getToken());
        }
    }
    PipelineInsightsService.prototype.getStackAnalyses = function (url, params) {
        var options = { headers: this.headers, observe: 'response' };
        if (params && params['access_token']) {
            this.headers.set('Authorization', 'Bearer ' + params['access_token']);
        }
        return this.http.get(url, options)
            .map(this.extractData)
            .catch(this.handleError);
    };
    PipelineInsightsService.prototype.extractData = function (res) {
        var body = res.body || {};
        body['statusCode'] = res.status;
        body['statusText'] = res.statusText;
        return body;
    };
    PipelineInsightsService.prototype.handleError = function (error) {
        var body = {};
        if (error.error instanceof ErrorEvent) {
            body = {
                statusText: error.error.message || error.error.toString()
            };
        }
        else if (error.status && error.statusText) {
            body = {
                status: error.status,
                statusText: error.statusText
            };
        }
        return Observable.throw(body);
    };
    PipelineInsightsService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    PipelineInsightsService.ctorParameters = function () { return [
        { type: HttpClient, },
        { type: AuthenticationService, },
    ]; };
    return PipelineInsightsService;
}());
export { PipelineInsightsService };
//# sourceMappingURL=pipeline-insights.service.js.map