import { Injectable } from '@angular/core';
import { HttpHeaders, HttpClient } from '@angular/common/http';
import { AuthenticationService } from 'ngx-login-client';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/catch';
import 'rxjs/operators/map';
var StackAnalysesService = /** @class */ (function () {
    function StackAnalysesService(http, auth) {
        this.http = http;
        this.auth = auth;
        this.headers = new HttpHeaders({ 'Content-Type': 'application/json' });
        this.cvssScale = {
            low: {
                start: 0.0,
                end: 3.9,
                iconClass: 'pficon pficon-warning-triangle-o',
                displayClass: 'progress-bar-warning'
            },
            medium: {
                start: 4.0,
                end: 6.9,
                iconClass: 'pficon pficon-warning-triangle-o',
                displayClass: 'progress-bar-warning'
            },
            high: {
                start: 7.0,
                end: 10.0,
                iconClass: 'pficon pficon-warning-triangle-o warning-red-color',
                displayClass: 'progress-bar-danger'
            }
        };
        if (this.auth.getToken() !== null) {
            this.headers.set('Authorization', 'Bearer ' + this.auth.getToken());
        }
    }
    StackAnalysesService.prototype.getStackAnalyses = function (url, params) {
        var options = { headers: this.headers, observe: 'response' };
        if (params && params['access_token']) {
            this.headers.set('Authorization', 'Bearer ' + params['access_token']);
        }
        return this.http.get(url, options)
            .map(this.extractData)
            .catch(this.handleError);
    };
    StackAnalysesService.prototype.getCvssObj = function (score) {
        if (score) {
            var iconClass = this.cvssScale.medium.iconClass;
            var displayClass = this.cvssScale.medium.displayClass;
            if (score >= this.cvssScale.high.start) {
                iconClass = this.cvssScale.high.iconClass;
                displayClass = this.cvssScale.high.displayClass;
            }
            return {
                iconClass: iconClass,
                displayClass: displayClass,
                value: score,
                percentScore: (score / 10 * 100)
            };
        }
    };
    StackAnalysesService.prototype.extractData = function (res) {
        var body = res.body || {};
        body['statusCode'] = res.status;
        body['statusText'] = res.statusText;
        return body;
    };
    StackAnalysesService.prototype.handleError = function (error) {
        var body = {};
        if (error.error instanceof ErrorEvent) {
            body = {
                statusText: error.error.message || error.error.toString()
            };
        }
        else if (error.status && error.statusText) {
            body = {
                status: error.status,
                statusText: error.statusText
            };
        }
        return Observable.throw(body);
    };
    StackAnalysesService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    StackAnalysesService.ctorParameters = function () { return [
        { type: HttpClient, },
        { type: AuthenticationService, },
    ]; };
    return StackAnalysesService;
}());
export { StackAnalysesService };
//# sourceMappingURL=stack-analyses.service.js.map