import { Injectable } from '@angular/core';
import { HttpHeaders, HttpClient } from '@angular/common/http';
import { AuthenticationService } from 'ngx-login-client';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/catch';
import 'rxjs/operators/map';
var ComponentFeedbackService = /** @class */ (function () {
    function ComponentFeedbackService(http, auth) {
        this.http = http;
        this.auth = auth;
        this.headers = new HttpHeaders({ 'Content-Type': 'application/json' });
        this.FEEDBACK_URL = '';
        if (this.auth.getToken() !== null) {
            this.headers.set('Authorization', 'Bearer ' + this.auth.getToken());
        }
    }
    ComponentFeedbackService.prototype.postFeedback = function (feedback) {
        var options = { headers: this.headers, observe: 'response' };
        var body = JSON.stringify(feedback.feedbackTemplate);
        this.FEEDBACK_URL = feedback.baseUrl + 'api/v1/submit-feedback';
        return this.http.post(this.FEEDBACK_URL, body, options)
            .map(this.extractData)
            .catch(this.handleError);
    };
    ComponentFeedbackService.prototype.extractData = function (res) {
        var body = res.body || {};
        body['statusCode'] = res.status;
        body['statusText'] = res.statusText;
        return body;
    };
    ComponentFeedbackService.prototype.handleError = function (error) {
        var body = {};
        if (error.error instanceof ErrorEvent) {
            body = {
                statusText: error.error.message || error.error.toString()
            };
        }
        else if (error.status && error.statusText) {
            body = {
                status: error.status,
                statusText: error.statusText
            };
        }
        return Observable.throw(body);
    };
    ComponentFeedbackService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    ComponentFeedbackService.ctorParameters = function () { return [
        { type: HttpClient, },
        { type: AuthenticationService, },
    ]; };
    return ComponentFeedbackService;
}());
export { ComponentFeedbackService };
//# sourceMappingURL=component-feedback.service.js.map